@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2017 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2018 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -37,6 +37,7 @@
 #include "CartDPCPlus.hxx"
 #include "CartE0.hxx"
 #include "CartE7.hxx"
+#include "CartE78K.hxx"
 #include "CartEF.hxx"
 #include "CartEFSC.hxx"
 #include "CartBF.hxx"
@@ -53,7 +54,6 @@
 #include "CartFA.hxx"
 #include "CartFA2.hxx"
 #include "CartFE.hxx"
-#include "CartMC.hxx"
 #include "CartMDM.hxx"
 #include "CartSB.hxx"
 #include "CartUA.hxx"
@@ -278,6 +278,8 @@ CartDetector::createFromImage(const BytePtr& image, uInt32 size, BSType type,
       return make_unique<CartridgeE0>(image, size, osystem.settings());
     case BSType::_E7:
       return make_unique<CartridgeE7>(image, size, osystem.settings());
+    case BSType::_E78K:
+      return make_unique<CartridgeE78K>(image, size, osystem.settings());
     case BSType::_EF:
       return make_unique<CartridgeEF>(image, size, osystem.settings());
     case BSType::_EFSC:
@@ -310,8 +312,6 @@ CartDetector::createFromImage(const BytePtr& image, uInt32 size, BSType type,
       return make_unique<CartridgeFA2>(image, size, osystem);
     case BSType::_FE:
       return make_unique<CartridgeFE>(image, size, osystem.settings());
-    case BSType::_MC:
-      return make_unique<CartridgeMC>(image, size, osystem.settings());
     case BSType::_MDM:
       return make_unique<CartridgeMDM>(image, size, osystem.settings());
     case BSType::_UA:
@@ -381,6 +381,8 @@ BSType CartDetector::autodetectType(const BytePtr& image, uInt32 size)
       type = BSType::_FE;
     else if(isProbably0840(image, size))
       type = BSType::_0840;
+    else if(isProbablyE78K(image, size))
+      type = BSType::_E78K;
     else
       type = BSType::_F8;
   }
@@ -470,8 +472,6 @@ BSType CartDetector::autodetectType(const BytePtr& image, uInt32 size)
       type = BSType::_4A50;
     else if(isProbablySB(image, size))
       type = BSType::_SB;
-    else
-      type = BSType::_MC;
   }
   else if(size == 256*1024)  // 256K
   {
@@ -754,6 +754,25 @@ bool CartDetector::isProbablyE7(const BytePtr& image, uInt32 size)
   return false;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool CartDetector::isProbablyE78K(const BytePtr& image, uInt32 size)
+{
+  // E78K cart bankswitching is triggered by accessing addresses
+  // $FE4 to $FE6 using absolute non-indexed addressing
+  // To eliminate false positives (and speed up processing), we
+  // search for only certain known signatures
+  uInt8 signature[3][3] = {
+    { 0xAD, 0xE4, 0xFF },  // LDA $FFE4
+    { 0xAD, 0xE5, 0xFF },  // LDA $FFE5
+    { 0xAD, 0xE6, 0xFF },  // LDA $FFE6
+  };
+  for(uInt32 i = 0; i < 3; ++i)
+    if(searchForBytes(image.get(), size, signature[i], 3, 1))
+      return true;
+
+  return false;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool CartDetector::isProbablyEF(const BytePtr& image, uInt32 size, BSType& type)
 {
